Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(888)

Unified Diff: base/syslog_logging.h

Issue 2946983002: Move eventlog_provider from //base/win to //chrome/common/win (Closed)
Patch Set: Add dep to chrome:common Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/BUILD.gn ('k') | base/syslog_logging.cc » ('j') | base/syslog_logging.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/syslog_logging.h
diff --git a/base/syslog_logging.h b/base/syslog_logging.h
index 74f35beaf1aab86beb06d39e8d272c4a7c413ec5..52252a5e32a7eab28335a140a5bb988c590f5688 100644
--- a/base/syslog_logging.h
+++ b/base/syslog_logging.h
@@ -7,6 +7,10 @@
#include "base/logging.h"
+#if defined(OS_WIN)
+#include <windows.h>
+#endif
+
namespace logging {
// Keep in mind that the syslog is always active regardless of the logging level
@@ -17,10 +21,14 @@ namespace logging {
#define SYSLOG(severity) \
SYSLOG_STREAM(severity)
-// Sets the name of the event source for logging to the Windows Event Log.
-// Call this function once before using the SYSLOG macro or otherwise it will
-// behave as a regular LOG macro.
-void BASE_EXPORT SetEventSourceName(const std::string& name);
+#if defined(OS_WIN)
+// Sets the name, category and event id of the event source for logging to the
+// Windows Event Log. Call this function once before using the SYSLOG macro or
+// otherwise it will behave as a regular LOG macro.
+void BASE_EXPORT SetEventSource(const std::string& name,
+ WORD category,
+ DWORD event_id);
+#endif // defined(OS_WIN)
// Creates a formatted message on the system event log. That would be the
// Application Event log on Windows and the messages log file on POSIX systems.
« no previous file with comments | « base/BUILD.gn ('k') | base/syslog_logging.cc » ('j') | base/syslog_logging.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698